==> xwiki-rendering-api-3.3-sources.jar: org/xwiki/rendering/parser/xml/ContentHandlerStreamParserFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.parser.xml;

import org.xwiki.component.annotation.ComponentRole;
import org.xwiki.rendering.listener.Listener;
import org.xwiki.rendering.syntax.Syntax;

/**
 * Create instances of {@link ContentHandlerStreamParser}.
 * 
 * @version $Id: 2b7694148fbe216b9f6e9b8c91e1092b2fc258b7 $
 * @since 3.3M1
 */
@ComponentRole
public interface ContentHandlerStreamParserFactory
{
    /**
     * @return the syntax the parser is implementing
     */
    Syntax getSyntax();

    /**
     * @param listener the listener to send rendering events to
     * @return the new {@link ContentHandlerStreamParser} instance.
     */
    ContentHandlerStreamParser createParser(Listener listener);
}

==> xwiki-rendering-api-4.1-sources.jar: org/xwiki/rendering/parser/xml/ContentHandlerStreamParserFactory.java <==
/*
 * See the NOTICE file distributed with this work for additional
 * information regarding copyright ownership.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.xwiki.rendering.parser.xml;

import org.xwiki.component.annotation.Role;
import org.xwiki.rendering.listener.Listener;
import org.xwiki.rendering.syntax.Syntax;

/**
 * Create instances of {@link ContentHandlerStreamParser}.
 * 
 * @version $Id$
 * @since 3.3M1
 */
@Role
public interface ContentHandlerStreamParserFactory
{
    /**
     * @return the syntax the parser is implementing
     */
    Syntax getSyntax();

    /**
     * @param listener the listener to send rendering events to
     * @return the new {@link ContentHandlerStreamParser} instance.
     */
    ContentHandlerStreamParser createParser(Listener listener);
}
